@@ -14,6 +14,9 @@ import re
 from time import time
 
 
+from tornadoez.mail import MailClient2
+
+
 
 # try:
 # from tornado.web import _UIModuleNamespace
@@ -276,8 +279,17 @@ class RequestHandler(tornado.web.RequestHandler):
         self.author = self.application.settings.get('author', '')
 
 
+        #mail client
+        _smtp_config = self.application.settings.get('smtp')
+
+        if _smtp_config:
+            self.smtp = MailClient2(_smtp_config)
+        else:
+            self.smtp = None
+
         # ez-hack-end
 
+
         # UIModules are available as both `modules` and `_tt_modules` in the
         # template namespace.  Historically only `modules` was available
         # but could be clobbered by user additions to the namespace.
